==> tdcommon-5.3-sources.jar: thredds/server/catalog/builder/FeatureCollectionRefBuilder.java <==
/*
 * Copyright (c) 1998 - 2014. University Corporation for Atmospheric Research/Unidata
 * Portions of this software were developed by the Unidata Program at the
 * University Corporation for Atmospheric Research.
 *
 * Access and use of this software shall impose the following obligations
 * and understandings on the user. The user is granted the right, without
 * any fee or cost, to use, copy, modify, alter, enhance and distribute
 * this software, and any derivative works thereof, and its supporting
 * documentation for any purpose whatsoever, provided that this entire
 * notice appears in all copies of the software, derivative works and
 * supporting documentation. Further, UCAR requests that the user credit
 * UCAR/Unidata in any publications that result from the use of this
 * software or in any product that includes this software. The names UCAR
 * and/or Unidata, however, may not be used in any advertising or publicity
 * to endorse or promote any products or commercial entity unless specific
 * written permission is obtained from UCAR/Unidata. The user also
 * understands that UCAR/Unidata is not obligated to provide the user with
 * any support, consulting, training or assistance of any kind with regard
 * to the use, operation and performance of this software nor to provide
 * the user with any updates, revisions, new versions or "bug fixes."
 *
 * THIS SOFTWARE IS PROVIDED BY UCAR/UNIDATA "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL UCAR/UNIDATA BE LIABLE FOR ANY SPECIAL,
 * INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING
 * FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
 * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
 * WITH THE ACCESS, USE OR PERFORMANCE OF THIS SOFTWARE.
 */

package thredds.server.catalog.builder;

import thredds.client.catalog.DatasetNode;
import thredds.client.catalog.builder.DatasetBuilder;
import thredds.server.catalog.FeatureCollectionRef;

/**
 * Builder of FeatureCollectionRef
 *
 * @author John
 * @since 1/17/2015
 */
public class FeatureCollectionRefBuilder extends DatasetBuilder {
  thredds.featurecollection.FeatureCollectionConfig config;
  private String context;

  public FeatureCollectionRefBuilder(DatasetBuilder parent, thredds.featurecollection.FeatureCollectionConfig config,
      String context) {
    super(parent);
    this.config = config;
    this.context = context;
  }

  public FeatureCollectionRefBuilder(DatasetBuilder parent, FeatureCollectionRef from) {
    super(parent, from);
    this.config = from.getConfig();
    this.context = "thredds";
  }

  public FeatureCollectionRef makeDataset(DatasetNode parent) {
    String xlink = "/" + context + "/catalog/" + config.path + "/catalog.xml";
    return new FeatureCollectionRef(parent, name, xlink, flds, accessBuilders, datasetBuilders, config);
  }
}

==> tdcommon-5.7-20250821.163036-6-sources.jar: thredds/server/catalog/builder/FeatureCollectionRefBuilder.java <==
/*
 * Copyright (c) 1998 - 2014. University Corporation for Atmospheric Research/Unidata
 * Portions of this software were developed by the Unidata Program at the
 * University Corporation for Atmospheric Research.
 *
 * Access and use of this software shall impose the following obligations
 * and understandings on the user. The user is granted the right, without
 * any fee or cost, to use, copy, modify, alter, enhance and distribute
 * this software, and any derivative works thereof, and its supporting
 * documentation for any purpose whatsoever, provided that this entire
 * notice appears in all copies of the software, derivative works and
 * supporting documentation. Further, UCAR requests that the user credit
 * UCAR/Unidata in any publications that result from the use of this
 * software or in any product that includes this software. The names UCAR
 * and/or Unidata, however, may not be used in any advertising or publicity
 * to endorse or promote any products or commercial entity unless specific
 * written permission is obtained from UCAR/Unidata. The user also
 * understands that UCAR/Unidata is not obligated to provide the user with
 * any support, consulting, training or assistance of any kind with regard
 * to the use, operation and performance of this software nor to provide
 * the user with any updates, revisions, new versions or "bug fixes."
 *
 * THIS SOFTWARE IS PROVIDED BY UCAR/UNIDATA "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL UCAR/UNIDATA BE LIABLE FOR ANY SPECIAL,
 * INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING
 * FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
 * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
 * WITH THE ACCESS, USE OR PERFORMANCE OF THIS SOFTWARE.
 */

package thredds.server.catalog.builder;

import thredds.client.catalog.DatasetNode;
import thredds.client.catalog.builder.DatasetBuilder;
import thredds.server.catalog.FeatureCollectionRef;
import ucar.unidata.util.StringUtil2;

/**
 * Builder of FeatureCollectionRef
 *
 * @author John
 * @since 1/17/2015
 */
public class FeatureCollectionRefBuilder extends DatasetBuilder {
  thredds.featurecollection.FeatureCollectionConfig config;
  private String context;

  public FeatureCollectionRefBuilder(DatasetBuilder parent, thredds.featurecollection.FeatureCollectionConfig config,
      String context) {
    super(parent);
    this.config = config;
    this.context = StringUtil2.trim(context, '/');
  }

  public FeatureCollectionRefBuilder(DatasetBuilder parent, FeatureCollectionRef from, String context) {
    super(parent, from);
    this.config = from.getConfig();
    this.context = StringUtil2.trim(context, '/');
  }

  /**
   * @deprecated Use {@link #FeatureCollectionRefBuilder(DatasetBuilder, FeatureCollectionRef, String)} instead
   */
  @Deprecated
  public FeatureCollectionRefBuilder(DatasetBuilder parent, FeatureCollectionRef from) {
    this(parent, from, "thredds");
  }

  public FeatureCollectionRef makeDataset(DatasetNode parent) {
    String xlink = "/" + context + "/catalog/" + config.path + "/catalog.xml";
    return new FeatureCollectionRef(parent, name, xlink, flds, accessBuilders, datasetBuilders, config);
  }
}
